@@ -10,7 +10,7 @@ from .typings import Command, BlocklessNodeType
 import re
 import yaml
 
-def create_worker_account(worker_name, faucet_url, type):
+def create_worker_account(worker_name, faucet_url, type, network="testnet"):
     current_file_dir = os.path.dirname(os.path.abspath(__file__))
     cli_tool_dir = os.path.dirname(current_file_dir)
     allora_chain_dir = os.path.join(cli_tool_dir, 'allora-chain')
@@ -75,15 +75,28 @@ def create_worker_account(worker_name, faucet_url, type):
         subprocess.run([
                         'curl',
                         '-Lvvv',
-                        f'{faucet_url}/send/testnet/{address}'
+                        f'{faucet_url}/send/{network}/{address}'
                     ], stdout=subprocess.DEVNULL)
         
-        print(colored(f"keys created and testnet-funded for this {type}. please check config.yaml for your address and mnemonic", "green"))
+        print(colored(f"keys created and {network}-funded for this {type}. please check config.yaml for your address and mnemonic", "green"))
         return mnemonic, hex_coded_pk, address
     else:
         print(colored("'make' is not available in the system's PATH. Please install it or check your PATH settings.", "red"))
         return ''
 
+def fundAddress(faucet_url, address, network="testnet"):
+    try:
+        subprocess.run([
+                        'curl',
+                        '-Lvvv',
+                        f'{faucet_url}/send/{network}/{address}'
+                    ], stdout=subprocess.DEVNULL)
+        
+        print(colored(f"address funded with {network}-faucet", "green"))
+        return address
+    except subprocess.CalledProcessError as e:
+        click.echo(f"error funding address: {e}", err=True)
+
 def print_allora_banner():
     """Prints an ASCII art styled banner for ALLORA."""
     banner_text = r"""
@@ -111,7 +124,7 @@ def generate_all_files(env: Environment, file_configs, command: Command, type, n
         if command == Command.INIT:
             file_path = os.path.join(os.getcwd(), f'{name}/{type}/{config["file_name"]}')
         elif command == Command.DEPLOY: 
-            file_path = os.path.join(os.getcwd(), f'{type}/{config["file_name"]}')
+            file_path = os.path.join(os.getcwd(), f'{config["file_name"]}')
 
         content = template.render(**config["context"])
         with open(file_path, 'w') as f:
@@ -173,7 +186,6 @@ def generateProdCompose(env: Environment, type):
 
         try:
             result = subprocess.run("chmod -R +rx ./data/scripts", shell=True, check=True, capture_output=True, text=True)
-            print(result)
         except subprocess.CalledProcessError as e:
             print(f"Command '{e.cmd}' returned non-zero exit status {e.returncode}.")
             if e.stderr:
@@ -214,9 +226,9 @@ def generateProdCompose(env: Environment, type):
             }
         ]
 
-        generate_all_files(env, file_configs, Command.DEPLOY)
+        generate_all_files(env, file_configs, Command.DEPLOY, type)
         cprint(f"production docker compose file generated to be deployed", 'green')
-        # cprint(f"please run chmod -R +rx ./data/scripts to grant script access to the image", 'yellow')
+        cprint(f"please run chmod -R +rx ./data/scripts to grant script access to the image", 'yellow')
     else:
         cprint("\nOperation cancelled.", 'red')
 
@@ -284,13 +296,13 @@ def blocklessNode(environment, env, type, name=None, topic=None):
                 }
             ]
 
-            generate_all_files(env, file_configs, Command.INIT, name)
+            generate_all_files(env, file_configs, Command.INIT, type, name)
 
             generateWorkerAccount(name, type)
         else:
             cprint("\nOperation cancelled.", 'red')
     elif environment == 'prod':
-        devComposePath = os.path.join(os.getcwd(), type, 'dev-docker-compose.yaml')
+        devComposePath = os.path.join(os.getcwd(), 'dev-docker-compose.yaml')
         if not os.path.exists(devComposePath):
             cprint(f"You must initialize the {type} on dev please run allocmd generate {type} --env dev --name <{type} name> --topic <topic id> and then run the prod generate in the directory created", 'red')
         else:
